@@ -6,14 +6,14 @@ from sphinx_celery import conf
 globals().update(conf.build_config(
     'kombu', __file__,
     project='Kombu',
-    version_dev='4.3',
-    version_stable='4.2',
-    canonical_url='http://docs.kombu.me',
-    webdomain='kombu.me',
+    version_dev='4.6',
+    version_stable='4.5',
+    canonical_url='https://kombu.readthedocs.io/',
+    webdomain='kombu.readthedocs.io',
     github_project='celery/kombu',
     author='Ask Solem & contributors',
     author_name='Ask Solem',
-    copyright='2009-2016',
+    copyright='2009-2019',
     publisher='Celery Project',
     html_logo='images/kombusmall.jpg',
     html_favicon='images/favicon.ico',
