@@ -1,36 +1,37 @@
-"""
-kombu.abstract
-==============
-
-Object utilities.
-
-"""
-from __future__ import absolute_import
+"""Object utilities."""
+from __future__ import absolute_import, unicode_literals
 
 from copy import copy
 
 from .connection import maybe_channel
 from .exceptions import NotBoundError
-from .utils import ChannelPromise
+from .five import python_2_unicode_compatible
+from .utils.functional import ChannelPromise
 
-__all__ = ['Object', 'MaybeChannelBound']
+__all__ = ('Object', 'MaybeChannelBound')
 
 
 def unpickle_dict(cls, kwargs):
     return cls(**kwargs)
 
 
+def _any(v):
+    return v
+
+
 class Object(object):
-    """Common base class supporting automatic kwargs->attributes handling,
-    and cloning."""
+    """Common base class.
+
+    Supports automatic kwargs->attributes handling, and cloning.
+    """
+
     attrs = ()
 
     def __init__(self, *args, **kwargs):
-        any = lambda v: v
         for name, type_ in self.attrs:
             value = kwargs.get(name)
             if value is not None:
-                setattr(self, name, (type_ or any)(value))
+                setattr(self, name, (type_ or _any)(value))
             else:
                 try:
                     getattr(self, name)
@@ -41,10 +42,10 @@ class Object(object):
         def f(obj, type):
             if recurse and isinstance(obj, Object):
                 return obj.as_dict(recurse=True)
-            return type(obj) if type else obj
-        return dict(
-            (attr, f(getattr(self, attr), type)) for attr, type in self.attrs
-        )
+            return type(obj) if type and obj is not None else obj
+        return {
+            attr: f(getattr(self, attr), type) for attr, type in self.attrs
+        }
 
     def __reduce__(self):
         return unpickle_dict, (self.__class__, self.as_dict())
@@ -53,8 +54,10 @@ class Object(object):
         return self.__class__(**self.as_dict())
 
 
+@python_2_unicode_compatible
 class MaybeChannelBound(Object):
     """Mixin for classes that can be bound to an AMQP channel."""
+
     _channel = None
     _is_bound = False
 
@@ -62,7 +65,7 @@ class MaybeChannelBound(Object):
     can_cache_declaration = False
 
     def __call__(self, channel):
-        """`self(channel) -> self.bind(channel)`"""
+        """`self(channel) -> self.bind(channel)`."""
         return self.bind(channel)
 
     def bind(self, channel):
@@ -91,11 +94,15 @@ class MaybeChannelBound(Object):
         """Callback called when the class is bound."""
         pass
 
-    def __repr__(self, item=''):
+    def __repr__(self):
+        return self._repr_entity(type(self).__name__)
+
+    def _repr_entity(self, item=''):
+        item = item or type(self).__name__
         if self.is_bound:
-            return '<%s bound to chan:%s>' % (
+            return '<{0} bound to chan:{1}>'.format(
                 item or type(self).__name__, self.channel.channel_id)
-        return '<unbound %s>' % (item, )
+        return '<unbound {0}>'.format(item)
 
     @property
     def is_bound(self):
@@ -108,8 +115,8 @@ class MaybeChannelBound(Object):
         channel = self._channel
         if channel is None:
             raise NotBoundError(
-                "Can't call method on %s not bound to a channel" % (
-                    self.__class__.__name__))
+                "Can't call method on {0} not bound to a channel".format(
+                    type(self).__name__))
         if isinstance(channel, ChannelPromise):
             channel = self._channel = channel()
         return channel
