@@ -1,4 +1,5 @@
-from __future__ import absolute_import
+"""Logging Utilities."""
+from __future__ import absolute_import, unicode_literals
 
 import logging
 import numbers
@@ -8,11 +9,11 @@ import sys
 from logging.handlers import WatchedFileHandler
 
 from .five import string_t
-from .utils import cached_property
 from .utils.encoding import safe_repr, safe_str
 from .utils.functional import maybe_evaluate
+from .utils.objects import cached_property
 
-__all__ = ['LogMixin', 'LOG_LEVELS', 'get_loglevel', 'setup_logging']
+__all__ = ('LogMixin', 'LOG_LEVELS', 'get_loglevel', 'setup_logging')
 
 try:
     LOG_LEVELS = dict(logging._nameToLevel)
@@ -24,21 +25,17 @@ LOG_LEVELS.setdefault(logging.FATAL, 'FATAL')
 DISABLE_TRACEBACKS = os.environ.get('DISABLE_TRACEBACKS')
 
 
-class NullHandler(logging.Handler):
-
-    def emit(self, record):
-        pass
-
-
 def get_logger(logger):
+    """Get logger by name."""
     if isinstance(logger, string_t):
         logger = logging.getLogger(logger)
     if not logger.handlers:
-        logger.addHandler(NullHandler())
+        logger.addHandler(logging.NullHandler())
     return logger
 
 
 def get_loglevel(level):
+    """Get loglevel by name."""
     if isinstance(level, string_t):
         return LOG_LEVELS[level]
     return level
@@ -50,15 +47,15 @@ def naive_format_parts(fmt):
         yield None if not e or not parts[i - 1] else e[0]
 
 
-def safeify_format(fmt, args,
-                   filters={'s': safe_str,
-                            'r': safe_repr}):
+def safeify_format(fmt, args, filters=None):
+    filters = {'s': safe_str, 'r': safe_repr} if not filters else filters
     for index, type in enumerate(naive_format_parts(fmt)):
         filt = filters.get(type)
         yield filt(args[index]) if filt else args[index]
 
 
 class LogMixin(object):
+    """Mixin that adds severity methods to any class."""
 
     def debug(self, *args, **kwargs):
         return self.log(logging.DEBUG, *args, **kwargs)
@@ -70,21 +67,19 @@ class LogMixin(object):
         return self.log(logging.WARN, *args, **kwargs)
 
     def error(self, *args, **kwargs):
-        return self._error(logging.ERROR, *args, **kwargs)
+        kwargs.setdefault('exc_info', True)
+        return self.log(logging.ERROR, *args, **kwargs)
 
     def critical(self, *args, **kwargs):
-        return self._error(logging.CRITICAL, *args, **kwargs)
-
-    def _error(self, severity, *args, **kwargs):
         kwargs.setdefault('exc_info', True)
-        if DISABLE_TRACEBACKS:
-            kwargs.pop('exc_info', None)
-        return self.log(severity, *args, **kwargs)
+        return self.log(logging.CRITICAL, *args, **kwargs)
 
     def annotate(self, text):
         return '%s - %s' % (self.logger_name, text)
 
     def log(self, severity, *args, **kwargs):
+        if DISABLE_TRACEBACKS:
+            kwargs.pop('exc_info', None)
         if self.logger.isEnabledFor(severity):
             log = self.logger.log
             if len(args) > 1 and isinstance(args[0], string_t):
@@ -134,6 +129,7 @@ class Log(LogMixin):
 
 
 def setup_logging(loglevel=None, logfile=None):
+    """Setup logging."""
     logger = logging.getLogger()
     loglevel = get_loglevel(loglevel or 'ERROR')
     logfile = logfile if logfile else sys.__stderr__
