@@ -20,6 +20,8 @@ from kombu.utils.json import loads, dumps
 from kombu.utils.objects import cached_property
 
 from . import virtual
+from .base import to_rabbitmq_queue_arguments
+
 
 E_SERVER_VERSION = """\
 Kombu requires MongoDB version 1.3+ (server is {0})\
@@ -286,6 +288,9 @@ class Channel(virtual.Channel):
                 options['readpreference'] = modes[options['readpreference']]
         return options
 
+    def prepare_queue_arguments(self, arguments, **kwargs):
+        return to_rabbitmq_queue_arguments(arguments, **kwargs)
+
     def _open(self, scheme='mongodb://'):
         hostname, dbname, conf = self._parse_uri(scheme=scheme)
 
@@ -303,6 +308,7 @@ class Channel(virtual.Channel):
         database = mongoconn[dbname]
 
         version_str = mongoconn.server_info()['version']
+        version_str = version_str.split('-')[0]
         version = tuple(map(int, version_str.split('.')))
 
         if version < (1, 3):
@@ -341,7 +347,7 @@ class Channel(virtual.Channel):
                 [('expire_at', 1)], expireAfterSeconds=0)
 
     def _create_client(self):
-        """Actualy creates connection."""
+        """Actually creates connection."""
         database = self._open()
         self._create_broadcast(database)
         self._ensure_indexes(database)
@@ -381,15 +387,15 @@ class Channel(virtual.Channel):
 
     def _create_broadcast_cursor(self, exchange, routing_key, pattern, queue):
         if pymongo.version_tuple >= (3, ):
-            query = dict(
-                filter={'queue': exchange},
-                cursor_type=CursorType.TAILABLE
-            )
+            query = {
+                'filter': {'queue': exchange},
+                'cursor_type': CursorType.TAILABLE,
+            }
         else:
-            query = dict(
-                query={'queue': exchange},
-                tailable=True
-            )
+            query = {
+                'query': {'queue': exchange},
+                'tailable': True,
+            }
 
         cursor = self.broadcast.find(**query)
         ret = self._broadcast_cursors[queue] = BroadcastCursor(cursor)
@@ -426,11 +432,9 @@ class Channel(virtual.Channel):
             return
 
         self.routing.update(
-            {'queue': queue}, {'$set': {'expire_at': expire_at}},
-            multiple=True)
+            {'queue': queue}, {'$set': {'expire_at': expire_at}}, multi=True)
         self.queues.update(
-            {'_id': queue}, {'$set': {'expire_at': expire_at}},
-            multiple=True)
+            {'_id': queue}, {'$set': {'expire_at': expire_at}}, multi=True)
 
     def get_now(self):
         """Return current time in UTC."""
