@@ -1,20 +1,22 @@
-"""
-kombu.utils.eventio
-===================
-
-Evented IO support for multiple platforms.
-
-"""
-from __future__ import absolute_import
+"""Selector Utilities."""
+from __future__ import absolute_import, unicode_literals
 
 import errno
+import math
 import select as __select__
 import socket
+import sys
 
 from numbers import Integral
 
+from . import fileno
+from .compat import detect_environment
+
+__all__ = ('poll',)
+
 _selectf = __select__.select
 _selecterr = __select__.error
+xpoll = getattr(__select__, 'poll', None)
 epoll = getattr(__select__, 'epoll', None)
 kqueue = getattr(__select__, 'kqueue', None)
 kevent = getattr(__select__, 'kevent', None)
@@ -38,37 +40,24 @@ KQ_NOTE_EXTEND = getattr(__select__, 'KQ_NOTE_EXTEND', 4)
 KQ_NOTE_ATTRIB = getattr(__select__, 'KQ_NOTE_ATTRIB', 8)
 KQ_NOTE_LINK = getattr(__select__, 'KQ_NOTE_LINK', 16)
 KQ_NOTE_RENAME = getattr(__select__, 'KQ_NOTE_RENAME', 32)
-KQ_NOTE_REVOKE = getattr(__select__, 'kQ_NOTE_REVOKE', 64)
-
-
-from kombu.syn import detect_environment
-
-from . import fileno
-from .compat import get_errno
-
-__all__ = ['poll']
+KQ_NOTE_REVOKE = getattr(__select__, 'KQ_NOTE_REVOKE', 64)
+POLLIN = getattr(__select__, 'POLLIN', 1)
+POLLOUT = getattr(__select__, 'POLLOUT', 4)
+POLLERR = getattr(__select__, 'POLLERR', 8)
+POLLHUP = getattr(__select__, 'POLLHUP', 16)
+POLLNVAL = getattr(__select__, 'POLLNVAL', 32)
 
 READ = POLL_READ = 0x001
 WRITE = POLL_WRITE = 0x004
 ERR = POLL_ERR = 0x008 | 0x010
 
 try:
-    SELECT_BAD_FD = set((errno.EBADF, errno.WSAENOTSOCK))
+    SELECT_BAD_FD = {errno.EBADF, errno.WSAENOTSOCK}
 except AttributeError:
-    SELECT_BAD_FD = set((errno.EBADF,))
+    SELECT_BAD_FD = {errno.EBADF}
 
 
-class Poller(object):
-
-    def poll(self, timeout):
-        try:
-            return self._poll(timeout)
-        except Exception as exc:
-            if get_errno(exc) != errno.EINTR:
-                raise
-
-
-class _epoll(Poller):
+class _epoll(object):
 
     def __init__(self):
         self._epoll = epoll()
@@ -77,26 +66,31 @@ class _epoll(Poller):
         try:
             self._epoll.register(fd, events)
         except Exception as exc:
-            if get_errno(exc) != errno.EEXIST:
+            if getattr(exc, 'errno', None) != errno.EEXIST:
                 raise
+        return fd
 
     def unregister(self, fd):
         try:
             self._epoll.unregister(fd)
-        except (socket.error, ValueError, KeyError):
+        except (socket.error, ValueError, KeyError, TypeError):
             pass
         except (IOError, OSError) as exc:
-            if get_errno(exc) != errno.ENOENT:
+            if getattr(exc, 'errno', None) not in (errno.ENOENT, errno.EPERM):
                 raise
 
-    def _poll(self, timeout):
-        return self._epoll.poll(timeout if timeout is not None else -1)
+    def poll(self, timeout):
+        try:
+            return self._epoll.poll(timeout if timeout is not None else -1)
+        except Exception as exc:
+            if getattr(exc, 'errno', None) != errno.EINTR:
+                raise
 
     def close(self):
         self._epoll.close()
 
 
-class _kqueue(Poller):
+class _kqueue(object):
     w_fflags = (KQ_NOTE_WRITE | KQ_NOTE_EXTEND |
                 KQ_NOTE_ATTRIB | KQ_NOTE_DELETE)
 
@@ -109,6 +103,7 @@ class _kqueue(Poller):
     def register(self, fd, events):
         self._control(fd, events, KQ_EV_ADD)
         self._active[fd] = events
+        return fd
 
     def unregister(self, fd):
         events = self._active.pop(fd, None)
@@ -151,8 +146,13 @@ class _kqueue(Poller):
             except ValueError:
                 pass
 
-    def _poll(self, timeout):
-        kevents = self._kcontrol(None, 1000, timeout)
+    def poll(self, timeout):
+        try:
+            kevents = self._kcontrol(None, 1000, timeout)
+        except Exception as exc:
+            if getattr(exc, 'errno', None) == errno.EINTR:
+                return
+            raise
         events, file_changes = {}, []
         for k in kevents:
             fd = k.ident
@@ -177,7 +177,69 @@ class _kqueue(Poller):
         self._kqueue.close()
 
 
-class _select(Poller):
+class _poll(object):
+
+    def __init__(self):
+        self._poller = xpoll()
+        self._quick_poll = self._poller.poll
+        self._quick_register = self._poller.register
+        self._quick_unregister = self._poller.unregister
+
+    def register(self, fd, events):
+        fd = fileno(fd)
+        poll_flags = 0
+        if events & ERR:
+            poll_flags |= POLLERR
+        if events & WRITE:
+            poll_flags |= POLLOUT
+        if events & READ:
+            poll_flags |= POLLIN
+        self._quick_register(fd, poll_flags)
+        return fd
+
+    def unregister(self, fd):
+        try:
+            fd = fileno(fd)
+        except socket.error as exc:
+            # we don't know the previous fd of this object
+            # but it will be removed by the next poll iteration.
+            if getattr(exc, 'errno', None) in SELECT_BAD_FD:
+                return fd
+            raise
+        self._quick_unregister(fd)
+        return fd
+
+    def poll(self, timeout, round=math.ceil,
+             POLLIN=POLLIN, POLLOUT=POLLOUT, POLLERR=POLLERR,
+             READ=READ, WRITE=WRITE, ERR=ERR, Integral=Integral):
+        timeout = 0 if timeout and timeout < 0 else round((timeout or 0) * 1e3)
+        try:
+            event_list = self._quick_poll(timeout)
+        except (_selecterr, socket.error) as exc:
+            if getattr(exc, 'errno', None) == errno.EINTR:
+                return
+            raise
+
+        ready = []
+        for fd, event in event_list:
+            events = 0
+            if event & POLLIN:
+                events |= READ
+            if event & POLLOUT:
+                events |= WRITE
+            if event & POLLERR or event & POLLNVAL or event & POLLHUP:
+                events |= ERR
+            assert events
+            if not isinstance(fd, Integral):
+                fd = fd.fileno()
+            ready.append((fd, events))
+        return ready
+
+    def close(self):
+        self._poller = None
+
+
+class _select(object):
 
     def __init__(self):
         self._all = (self._rfd,
@@ -192,13 +254,14 @@ class _select(Poller):
             self._wfd.add(fd)
         if events & READ:
             self._rfd.add(fd)
+        return fd
 
     def _remove_bad(self):
         for fd in self._rfd | self._wfd | self._efd:
             try:
                 _selectf([fd], [], [], 0)
             except (_selecterr, socket.error) as exc:
-                if get_errno(exc) in SELECT_BAD_FD:
+                if getattr(exc, 'errno', None) in SELECT_BAD_FD:
                     self.unregister(fd)
 
     def unregister(self, fd):
@@ -207,22 +270,22 @@ class _select(Poller):
         except socket.error as exc:
             # we don't know the previous fd of this object
             # but it will be removed by the next poll iteration.
-            if get_errno(exc) in SELECT_BAD_FD:
+            if getattr(exc, 'errno', None) in SELECT_BAD_FD:
                 return
             raise
         self._rfd.discard(fd)
         self._wfd.discard(fd)
         self._efd.discard(fd)
 
-    def _poll(self, timeout):
+    def poll(self, timeout):
         try:
             read, write, error = _selectf(
                 self._rfd, self._wfd, self._efd, timeout,
             )
         except (_selecterr, socket.error) as exc:
-            if get_errno(exc) == errno.EINTR:
+            if getattr(exc, 'errno', None) == errno.EINTR:
                 return
-            elif get_errno(exc) in SELECT_BAD_FD:
+            elif getattr(exc, 'errno', None) in SELECT_BAD_FD:
                 return self._remove_bad()
             raise
 
@@ -254,12 +317,14 @@ def _get_poller():
     elif epoll:
         # Py2.6+ Linux
         return _epoll
-    elif kqueue:
-        # Py2.6+ on BSD / Darwin
-        return _select  # was: _kqueue
+    elif kqueue and 'netbsd' in sys.platform:
+        return _kqueue
+    elif xpoll:
+        return _poll
     else:
         return _select
 
 
 def poll(*args, **kwargs):
+    """Create new poller instance."""
     return _get_poller()(*args, **kwargs)
