@@ -236,9 +236,12 @@ class test_Hub:
 
         poller = self.hub.poller
         self.hub.stop()
-        self.hub._ready = set()
+        mock_callback = Mock()
+        self.hub._ready = set([mock_callback])
         self.hub.close()
         poller.close.assert_called_with()
+        mock_callback.assert_called_once_with()
+        assert self.hub._ready == set()
 
     def test_poller_regeneration_on_access(self):
         self.hub = Hub()
