@@ -2,8 +2,8 @@ from __future__ import absolute_import, unicode_literals
 
 import io
 import pytest
-import sys
 import warnings
+import socket
 
 from case import MagicMock, Mock, patch
 
@@ -12,8 +12,8 @@ from kombu.compression import compress
 from kombu.exceptions import ResourceError, ChannelError
 from kombu.transport import virtual
 from kombu.utils.uuid import uuid
+from kombu.five import PY3, monotonic
 
-PY3 = sys.version_info[0] == 3
 PRINT_FQDN = 'builtins.print' if PY3 else '__builtin__.print'
 
 
@@ -553,9 +553,16 @@ class test_Transport:
         self.transport = client().transport
 
     def test_custom_polling_interval(self):
-        x = client(transport_options=dict(polling_interval=32.3))
+        x = client(transport_options={'polling_interval': 32.3})
         assert x.transport.polling_interval == 32.3
 
+    def test_timeout_over_polling_interval(self):
+        x = client(transport_options=dict(polling_interval=60))
+        start = monotonic()
+        with pytest.raises(socket.timeout):
+            x.transport.drain_events(x, timeout=.5)
+            assert monotonic() - start < 60
+
     def test_close_connection(self):
         c1 = self.transport.create_channel(self.transport)
         c2 = self.transport.create_channel(self.transport)
